/*
 * Copyright (C) 2011  Thomas McGuire <mcguire@kde.org>
 * Copyright (C) 2011  Alexander Potashev <aspotashev@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) version 3, or any
 * later version accepted by the membership of KDE e.V. (or its
 * successor approved by the membership of KDE e.V.), which shall
 * act as a proxy defined in Section 6 of version 3 of the license.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */

// This file is not available to library's users
#ifndef UTIL_H
#define UTIL_H

#include <libkvkontakte/apppermissions.h>

#include <KDE/KDateTime>

#include <QStringList>

/**
 * Convert a QString containing a UNIX timestamp to a KDateTime object
 */
KDateTime unixTimeToKDateTime(const QString &unixTime);

QStringList appPermissionsToStringList(Vkontakte::AppPermissions::Value permissions);
Vkontakte::AppPermissions::Value appPermissionsFromStringList(QStringList permissions);

#endif // UTIL_H
